@@ -25,31 +25,31 @@ __all__ = [
 class Box(FmtConv):
     """fmtconv's box resizer."""
 
-    kernel = 'box'
+    _kernel = 'box'
 
 
 class BlackMan(FmtConv):
     """fmtconv's blackman resizer."""
 
-    kernel = 'blackman'
+    _kernel = 'blackman'
 
 
 class BlackManMinLobe(FmtConv):
     """fmtconv's blackmanminlobe resizer."""
 
-    kernel = 'blackmanminlobe'
+    _kernel = 'blackmanminlobe'
 
 
 class Sinc(FmtConv):
     """fmtconv's sinc resizer."""
 
-    kernel = 'sinc'
+    _kernel = 'sinc'
 
 
 class Gaussian(FmtConv):
     """fmtconv's gaussian resizer."""
 
-    kernel = 'gaussian'
+    _kernel = 'gaussian'
 
     def __init__(self, curve: int = 30, **kwargs: Any) -> None:
         super().__init__(a1=curve, **kwargs)
@@ -63,49 +63,49 @@ class NearestNeighbour(Gaussian):
 
 
 class EwaJinc(Placebo):
-    kernel = 'ewa_jinc'
+    _kernel = 'ewa_jinc'
 
     def __init__(self, taps: int = 3, **kwargs: Any) -> None:
         super().__init__(taps, None, None, **kwargs)
 
 
 class EwaLanczos(Placebo):
-    kernel = 'ewa_lanczos'
+    _kernel = 'ewa_lanczos'
 
     def __init__(self, taps: int = 3, **kwargs: Any) -> None:
         super().__init__(taps, None, None, **kwargs)
 
 
 class EwaGinseng(Placebo):
-    kernel = 'ewa_ginseng'
+    _kernel = 'ewa_ginseng'
 
     def __init__(self, taps: int = 3, **kwargs: Any) -> None:
         super().__init__(taps, None, None, **kwargs)
 
 
 class EwaHann(Placebo):
-    kernel = 'ewa_hann'
+    _kernel = 'ewa_hann'
 
     def __init__(self, taps: int = 3, **kwargs: Any) -> None:
         super().__init__(taps, None, None, **kwargs)
 
 
 class EwaHannSoft(Placebo):
-    kernel = 'haasnsoft'
+    _kernel = 'haasnsoft'
 
     def __init__(self, taps: int = 3, **kwargs: Any) -> None:
         super().__init__(taps, None, None, **kwargs)
 
 
 class EwaRobidoux(Placebo):
-    kernel = 'ewa_robidoux'
+    _kernel = 'ewa_robidoux'
 
     def __init__(self, **kwargs: Any) -> None:
         super().__init__(None, None, None, **kwargs)
 
 
 class EwaRobidouxSharp(Placebo):
-    kernel = 'ewa_robidouxsharp'
+    _kernel = 'ewa_robidouxsharp'
 
     def __init__(self, **kwargs: Any) -> None:
         super().__init__(None, None, None, **kwargs)
